.. _sage.graphs:

Graph Theory
============


Graph objects and methods
-------------------------

.. toctree::
   :maxdepth: 1

   sage/graphs/generic_graph
   sage/graphs/graph
   sage/graphs/digraph
   sage/graphs/bipartite_graph
   sage/graphs/matching_covered_graph
   sage/graphs/views

Constructors and databases
--------------------------

.. toctree::
   :maxdepth: 1

   sage/graphs/graph_generators
   sage/graphs/digraph_generators
   sage/graphs/graph_generators_pyx
   sage/graphs/graph_database
   sage/graphs/strongly_regular_db
   sage/graphs/generators/distance_regular
   sage/graphs/generators/classical_geometries
   sage/graphs/generators/families
   sage/graphs/generators/basic
   sage/graphs/generators/chessboard
   sage/graphs/generators/intersection
   sage/graphs/generators/platonic_solids
   sage/graphs/generators/random
   sage/graphs/generators/smallgraphs
   sage/graphs/generators/world_map

   sage/graphs/isgci


Low-level implementation
------------------------

.. toctree::
   :maxdepth: 1

   sage/graphs/base/overview
   sage/graphs/base/c_graph
   sage/graphs/base/sparse_graph
   sage/graphs/base/dense_graph
   sage/graphs/base/static_dense_graph
   sage/graphs/base/static_sparse_graph
   sage/graphs/base/static_sparse_backend
   sage/graphs/base/graph_backends
   sage/graphs/base/boost_graph

Hypergraphs
-----------

.. toctree::
   :maxdepth: 1

   sage/graphs/hypergraph_generators
   sage/combinat/designs/incidence_structures


Libraries of algorithms
-----------------------

.. toctree::
   :maxdepth: 1

   sage/graphs/graph_coloring
   sage/graphs/cliquer
   sage/graphs/centrality
   sage/graphs/asteroidal_triples
   sage/graphs/independent_sets
   sage/graphs/cographs
   sage/graphs/comparability
   sage/graphs/line_graph
   sage/graphs/spanning_tree
   sage/graphs/pq_trees
   sage/graphs/trees
   sage/graphs/matching
   sage/graphs/matchpoly
   sage/graphs/genus
   sage/graphs/lovasz_theta
   sage/graphs/schnyder
   sage/graphs/planarity
   sage/graphs/traversals
   sage/graphs/graph_plot
   sage/graphs/graph_plot_js
   sage/graphs/graph_decompositions/tree_decomposition
   sage/graphs/graph_decompositions/vertex_separation
   sage/graphs/graph_decompositions/rankwidth
   sage/graphs/graph_decompositions/bandwidth
   sage/graphs/graph_decompositions/cutwidth
   sage/graphs/graph_decompositions/graph_products
   sage/graphs/graph_decompositions/slice_decomposition
   sage/graphs/graph_decompositions/modular_decomposition
   sage/graphs/graph_decompositions/clique_separators
   sage/graphs/convexity_properties
   sage/graphs/weakly_chordal
   sage/graphs/distances_all_pairs
   sage/graphs/graph_latex
   sage/graphs/graph_editor
   sage/graphs/graph_list
   sage/graphs/graph_input
   sage/graphs/hyperbolicity
   sage/graphs/tutte_polynomial
   sage/graphs/partial_cube
   sage/graphs/path_enumeration
   sage/graphs/generic_graph_pyx
   sage/graphs/orientations
   sage/graphs/connectivity
   sage/graphs/edge_connectivity
   sage/graphs/domination

.. include:: ../footer.txt
